## Защита форм сайта от интернет-ботов с Google reCAPTCHA v3

Предназначен для плагинов `comments`, `feedback`, а также для формы регистрации пользователей на сайте.

Плагин запрашивает у сервиса Google оценку действий пользователя без его участия для блокирования отправки форм ботами, которые чаще всего спамят.

### Системные требования

Перед использованием плагина вам необходимо убедиться, что ваш сервер соответствует следующим требованиям:

 - PHP ^7.3|^8.0
 - [irbees2008/ng-helpers](https://github.com/irbees2008/ng-helpers)

> Плагин **irbees2008/ng-helpers** должен быть обязательно включен.

### Подключение

 > Перед обновлением плагина, отключите его в панели управлении. Старую версию также нужно удалить с сервера.
 >
 > Те же самые манипуляции относятся и к старой версии плагина `ggg_recaptcha`.

Плагин выпускается в двух вариациях, каждая из которых поддерживает свой тип кодировки: UTF-8 и Windows-1251. Для подключения вы можете просто скачать плагин в необходимой для вашего проекта кодировке:

 - [UTF-8](https://codeload.github.com/irbees2008/ng-grecaptcha/zip/master)
 - [Windows-1251](https://codeload.github.com/irbees2008/ng-grecaptcha/zip/windows-1251)

<!-- Либо воспользуйтесь менеджером Composer:

```bash
composer require irbees2008/ng-grecaptcha
``` -->

 > Обратите внимание, что кодировка UTF-8 является основной.

### Настройка

 1. Перед использованием плагина зарегистрируйтесь и получите Ключ и Секретный ключ reCAPTCHA v3 [здесь](https://g.co/recaptcha/v3).
 1. Активируйте плагин `ng-grecaptcha` в админ. панели.
 1. Вставьте Ключ и Секретный ключ в соответствующие поля.
 1. Никаких дополнительных действий с плагином не требуется.

Теперь на вашем сайте в правом нижнем углу информационный блок от reCAPTCHA.

При использовании опции **Встраивать на страницу файл JavaScript из шаблона**, вы можете отслеживать действия пользователей, разграничивая их в [консоли администрирования](https://g.co/recaptcha/admin/). Для этого необходимо к каждой из форм добавлять соответствующий идентификатор.

Например, для формы регистрации пользователей это может выглядеть так:

```html
<!-- \templates\ВАШ_ШАБЛОН\registration.tpl -->

<form id="register_user" ...>
    <!-- Остальной код формы -->
</form>
```

### Использование

#### Плагин `comments`

Для использования в плагине `comments`, отредактируйте шаблон формы, добавив скрытое поле перед закрывающим тегом `</form>`:

```html
<!-- \templates\ВАШ_ШАБЛОН\plugins\comments\comments.form.tpl -->

<input type="hidden" name="g-recaptcha-response" value="" />
```

В том случае, если вы используете технологию AJAX для отправки комментариев, то вам необходимо добавить значение поля ввода капчи до того, как будет отправлен AJAX запрос вашим JavaScript.

Например, в этом же шаблоне добавить в секции `script` после `[not-logged] ... [/not-logged]`:

```javascript
cajax.setVar('g-recaptcha-response', form['g-recaptcha-response'].value);
```

#### Плагин `feedback`

Для использования в плагине `feedback`, отредактируйте шаблон формы, добавив скрытое поле перед закрывающим тегом `</form>`:

```html
<!-- \templates\ВАШ_ШАБЛОН\plugins\feedback\site.form.tpl -->

<input type="hidden" name="g-recaptcha-response" value="" />
```

#### Регистрационная форма

Для использования в форме регистрации пользователей, отредактируйте шаблон формы, добавив скрытое поле перед закрывающим тегом `</form>`:

```html
<!-- \templates\ВАШ_ШАБЛОН\registration.tpl -->

<input type="hidden" name="g-recaptcha-response" value="" />
```

#### Формы в модальных окнах

Для использования в формах модальных окон, отредактируйте шаблон формы, добавив скрытое поле перед закрывающим тегом `</form>`:

```html
<input type="hidden" name="g-recaptcha-response" value="" />
```

### Лицензия

`ng-grecaptcha` - программное обеспечение с открытым исходным кодом, распространяющееся по лицензии [MIT](LICENSE).
